@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.2.10
+# Version   : 0.2.13
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -504,8 +504,8 @@ class AFM:
             fig.add_trace(go.Scatter(y = self.approach_raw[curve_number], x = self.z_approach_raw[curve_number], mode='lines', name = 'Approach curve (raw)'))
             fig.add_trace(go.Scatter(y = self.retract_raw[curve_number], x = self.z_withdraw_raw[curve_number], mode='lines', name = 'Retract curve (raw)'))
             fig.update_layout(
-                yaxis_title_text='Force (nN)',
-                xaxis_title_text='Piezo position (nm)',
+                yaxis_title_text='Force (N)',
+                xaxis_title_text='Piezo position (m)',
             )
             fig.show()
 
@@ -588,10 +588,10 @@ class AFM:
                     self.retract[:,i] = adjusted_retract
 
                 else:
-                    self.z_approach[:,i] = _z_a[::-1] * -1
-                    self.z_withdraw[:,i] = _z_w[::-1] * -1
-                    self.approach[:,i] = adjusted_approach[::-1]
-                    self.retract[:,i] = adjusted_retract[::-1]
+                    self.z_approach[:,i] = _z_a[::-1] * -1 * 1e9
+                    self.z_withdraw[:,i] = _z_w[::-1] * -1 * 1e9
+                    self.approach[:,i] = adjusted_approach[::-1] * 1e9
+                    self.retract[:,i] = adjusted_retract[::-1] * 1e9
 
                 i += 1
 
@@ -617,7 +617,7 @@ class AFM:
             try:
                 j = 0
 
-                while _approach[j] > 0:
+                while _approach[j] > 0 or np.isnan(_approach[j]):
                     j += 1
 
                 y = _z[j-1], _z[j]
@@ -986,8 +986,8 @@ class AFM:
             _approach = self.approach[:,curve_number]
             _z = self.z_approach[:,curve_number]
 
-            force = _approach[0] * 1e-9
-            depth = _z[0] * 1e-9
+            force = _approach[np.isfinite(_approach)][0] * 1e-9
+            depth = _z[np.isfinite(_approach)][0] * 1e-9
             ratio = depth / indenter_radius
 
             term_1 = (4/3)
